@@ -3,3 +3,8 @@ from configDmanager._format import FormatExecutor
 from configDmanager._configmanager import ConfigManager
 
 import_config = ConfigManager.import_config
+export_config = ConfigManager.export_config
+update_config = ConfigManager.update_config
+
+
+__version__ = '0.2.0'
