@@ -14,24 +14,35 @@ class ConfigManager:
                        'yml': YamlType,
                        'yaml': YamlType}
     default_export_type = 'json'
+
     @classmethod
     def import_config(cls, name, path=None, type_=None):
-        level = 0
-        if name.startswith('.'):
-            if not path:
-                path = os.getcwd()
-            for character in name:
-                if character != '.':
-                    break
-                level += 1
-        return cls.__config_import(name[level:], path, level, type_)
+        level, path = cls.__level_parse(name, path)
+        return cls.__config_import(name[level:], path, level, type_)[0]
+
+    @classmethod
+    def update_config(cls, mod, name, path=None, type_=None):
+        level, path = cls.__level_parse(name, path)
+        config, name_base, c_path = cls.__config_import(name[level:], path, level, type_)
+        if isinstance(mod, dict) or isinstance(mod, Config):
+            config.update(mod)
+        elif callable(mod):
+            config.update(mod(config))
+        else:
+            raise ValueError('mod must be a dict, Config or a callable that returns a dict or a Config')
+        cls.export_config(config, name_base, c_path, type_)
+        return config
+
+    @classmethod
+    def export_config(cls, config, name, path=None, type_=None):
+        level, path = cls.__level_parse(name, path)
+        return cls.__config_export(config, name[level:], path, level, type_)
 
     @classmethod
     def export_config_file(cls, obj, config_name=None, path=None, type_=None, **kwargs):
         config_dict = obj.to_dict()
-        config_dict['__name'] = config_name
-        type_ = config_dict.get('__type', None) if type_ is None else type_
-        type_ = type_ if type_ else cls.default_export_type
+        type_ = type_ or config_dict.get('__type', cls.default_export_type)
+        cls.__set_metadata(config_dict, obj, config_name, type_)
         config_path = cls.__get_config_path(config_name if config_name else obj.get_name() or obj.__name__, path, type_)
         with open(config_path, 'w') as config_file:
             cls.supported_types[type_].export_config(config_dict, config_file, **kwargs)
@@ -59,21 +70,21 @@ class ConfigManager:
 
     @classmethod
     def __config_import(cls, name, path, level=0, type_=None):
-        cls.__sanity_check(name, path, level)
-        base, _, name_base = name.rpartition('.')
-        base = base.replace('.', '/')
         for c_path in chain([path], sys.path):
             try:
                 if c_path:
-                    cls.__sanity_check(name, c_path, level)
-                    c_path = Path(c_path)
-                    c_path = (c_path.parent if level == 2 else c_path) / base
-                    return cls.__load_config(name_base, c_path, type_)
+                    name_base, c_path = cls.__parse_path(name, c_path, level)
+                    return cls.__load_config(name_base, c_path, type_), name_base, c_path
             except (FileNotFoundError, PermissionError):
                 pass
 
         raise ConfigNotFoundError(name, path)
 
+    @classmethod
+    def __config_export(cls, config, name, path=None, level=0, type_=None):
+        name_base, c_path = cls.__parse_path(name, path or os.getcwd(), level)
+        return cls.export_config_file(config, name_base, c_path, type_)
+
     @classmethod
     def __get_config_path_and_type(cls, config_name, path, type_=None):
         if type_ is None:
@@ -105,6 +116,15 @@ class ConfigManager:
         else:
             raise FileNotFoundError
 
+    @classmethod
+    def __parse_path(cls, name, path, level):
+        cls.__sanity_check(name, path, level)
+        base, _, name_base = name.rpartition('.')
+        base = base.replace('.', '/')
+        c_path = Path(path)
+        c_path = (c_path.parent if level == 2 else c_path) / base
+        return name_base, c_path
+
     @staticmethod
     def __sanity_check(name, path, level):
         """Verify arguments are "sane"."""
@@ -125,3 +145,25 @@ class ConfigManager:
     @staticmethod
     def __get_config_path(config_name, path, type_=None):
         return Path(path) / (config_name + f'.{type_}' if type_ else '')
+
+    @staticmethod
+    def __level_parse(name, path=None):
+        level = 0
+        if name.startswith('.'):
+            if not path:
+                path = os.getcwd()
+            for character in name:
+                if character != '.':
+                    break
+                level += 1
+        return level, path
+
+    @staticmethod
+    def __set_metadata(config_dict, obj, config_name, type_):
+        config_dict['__name'] = config_name
+        parent = obj.get_parent()
+        parent_type = parent.get('__type', None) if parent else None
+        if parent_type:
+            config_dict['__parent_type'] = parent_type
+        config_dict['__type'] = type_
+        return config_dict
